Struct rat_input::date_input::DateInputState

source ·
pub struct DateInputState {
    pub widget: MaskedInputState,
    pub non_exhaustive: NonExhaustive,
    /* private fields */
}
State.

Use DateInputState::new(_pattern_) to set the date pattern.

Fields

widget: MaskedInputState

uses MaskedInputState for the actual functionality.

non_exhaustive: NonExhaustive

Implementations

source

impl DateInputState

source

pub fn new<S: AsRef<str>>(pattern: S) -> Result<Self, Error>

source

pub fn new_localized<S: AsRef<str>>( pattern: S, locale: Locale ) -> Result<Self, Error>

source

pub fn clear(&mut self)

Reset to empty.

source

pub fn format(&self) -> &str

chrono format string.

source

pub fn locale(&self) -> Locale

chrono locale.

source

pub fn set_format<S: AsRef<str>>(&mut self, pattern: S) -> Result<(), Error>

chrono format string.

generates a mask according to the format and overwrites whatever set_mask() did.

source

pub fn set_format_loc<S: AsRef<str>>( &mut self, pattern: S, locale: Locale ) -> Result<(), Error>

chrono format string.

generates a mask according to the format and overwrites whatever set_mask() did.

source

pub fn value(&self) -> Result<NaiveDate, ParseError>

Parses the text according to the given pattern.

source

pub fn set_value(&mut self, date: NaiveDate)

Set the date value.

source

pub fn select_all(&mut self)

Select all text.

source

pub fn screen_cursor(&self) -> Option<(u16, u16)>

Screen position of the cursor for rendering.