Struct rat_input::date_input::DateInputState
source · pub struct DateInputState {
pub widget: MaskedInputState,
pub non_exhaustive: NonExhaustive,
/* private fields */
}Expand description
State.
Use DateInputState::new(_pattern_) to set the date pattern.
Fields
widget: MaskedInputStateuses MaskedInputState for the actual functionality.
non_exhaustive: NonExhaustiveImplementations
sourceimpl DateInputState
impl DateInputState
pub fn new<S: AsRef<str>>(pattern: S) -> Result<Self, Error>
pub fn new_localized<S: AsRef<str>>( pattern: S, locale: Locale ) -> Result<Self, Error>
sourcepub fn set_format<S: AsRef<str>>(&mut self, pattern: S) -> Result<(), Error>
pub fn set_format<S: AsRef<str>>(&mut self, pattern: S) -> Result<(), Error>
chrono format string.
generates a mask according to the format and overwrites whatever set_mask() did.
sourcepub fn set_format_loc<S: AsRef<str>>(
&mut self,
pattern: S,
locale: Locale
) -> Result<(), Error>
pub fn set_format_loc<S: AsRef<str>>( &mut self, pattern: S, locale: Locale ) -> Result<(), Error>
chrono format string.
generates a mask according to the format and overwrites whatever set_mask() did.
sourcepub fn value(&self) -> Result<NaiveDate, ParseError>
pub fn value(&self) -> Result<NaiveDate, ParseError>
Parses the text according to the given pattern.
sourcepub fn select_all(&mut self)
pub fn select_all(&mut self)
Select all text.
sourcepub fn screen_cursor(&self) -> Option<(u16, u16)>
pub fn screen_cursor(&self) -> Option<(u16, u16)>
Screen position of the cursor for rendering.